==> jc-1.4.0.tar.gz: java/rmi/server/RMIClassLoader__24CacheKey.h <==
// class java.rmi.server.RMIClassLoader$CacheKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b7e1766b3cb3e6cc java_rmi_server_RMIClassLoader__24CacheKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMIClassLoader__24CacheKey_H_
#define _JC_java_rmi_server_RMIClassLoader__24CacheKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$refs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object	_jc_java_rmi_server_RMIClassLoader__24CacheKey$object;

typedef const struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$_init$8d67b1764832659f(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern jboolean _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$equals$765814146a5bf75d(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader__24CacheKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$equals$765814146a5bf75d;
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*equals$765814146a5bf75d)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *);
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods	java_rmi_server_RMIClassLoader__24CacheKey;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs {
	struct _jc_java_lang_String$object	*mCodeBase;
	struct _jc_java_lang_ClassLoader$object	*mContextClassLoader;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$refs {
    _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs	java_rmi_server_RMIClassLoader__24CacheKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs	java_rmi_server_RMIClassLoader__24CacheKey;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object {
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype _jc_java_rmi_server_RMIClassLoader__24CacheKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoader__24CacheKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoader__24CacheKey$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoader__24CacheKey_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/RMIClassLoader__24CacheKey.h <==
// class java.rmi.server.RMIClassLoader$CacheKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b7e1766b3cb3e6cc java_rmi_server_RMIClassLoader__24CacheKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMIClassLoader__24CacheKey_H_
#define _JC_java_rmi_server_RMIClassLoader__24CacheKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$refs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$refs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs	_jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object	_jc_java_rmi_server_RMIClassLoader__24CacheKey$object;

typedef const struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$_init$8d67b1764832659f(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$equals$765814146a5bf75d(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_server_RMIClassLoader__24CacheKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader__24CacheKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$equals$765814146a5bf75d;
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_server_RMIClassLoader__24CacheKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$765814146a5bf75d)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vmethods	java_rmi_server_RMIClassLoader__24CacheKey;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs {
	struct _jc_java_lang_String$object	*mCodeBase;
	struct _jc_java_lang_ClassLoader$object	*mContextClassLoader;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$refs {
    _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_refs	java_rmi_server_RMIClassLoader__24CacheKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMIClassLoader__24CacheKey$sub_nonrefs	java_rmi_server_RMIClassLoader__24CacheKey;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoader__24CacheKey$object {
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoader__24CacheKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoader__24CacheKey$vtype _jc_java_rmi_server_RMIClassLoader__24CacheKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoader__24CacheKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoader__24CacheKey$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoader__24CacheKey_H_ */
